@@ -4,14 +4,9 @@
 */
 
 /*
-** $Id: cginocache.c,v 1.5 2003/03/23 01:35:05 mrsam Exp $
+** $Id: cginocache.c,v 1.6 2004/10/21 01:12:57 mrsam Exp $
 */
-#if HAVE_LIBFCGI
-#include <stdlib.h>
-#include "fcgi_stdio.h"
-#else
 #include	<stdio.h>
-#endif
 
 void cginocache()
 {
