@@ -16,7 +16,7 @@
 extern "C" {
 #endif
 
-static const char bofh_h_rcsid[]="$Id: bofh.h,v 1.4 2001/11/16 13:00:46 mrsam Exp $";
+static const char bofh_h_rcsid[]="$Id: bofh.h,v 1.5 2004/08/16 23:26:17 mrsam Exp $";
 
 struct bofh_list {
 	struct bofh_list *next;
@@ -30,6 +30,10 @@ int bofh_chkbadfrom(const char *);
 int bofh_chkspamtrap(const char *);
 struct bofh_list *bofh_chkfreemail(const char *);
 int bofh_chkbadmx(const char *);
+int bofh_checkspf(const char *envvarname,
+		  const char *defaultValue, const char *keyword);
+int bofh_checkspf_status(const char *envvarname,
+			 const char *defaultValue, const char *keyword);
 
 extern unsigned max_bofh;
 extern int max_bofh_ishard;
