@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -153,8 +153,7 @@ int main(int argc, char **argv)
 		}
 		if (p == 0)
 		{
-			close(3);
-			dup(pipefd[1]);
+			dup2(pipefd[1], 3);
 			close(pipefd[1]);
 			close(pipefd[0]);
 			while ((p=fork()) == -1)
@@ -172,10 +171,8 @@ int main(int argc, char **argv)
 				signal(SIGHUP, SIG_IGN);
 				close(0);
 				open("/dev/null", O_RDWR);
-				close(1);
-				dup(0);
-				close(2);
-				dup(0);
+				dup2(0, 1);
+				dup2(0, 2);
 			/* See if we can disconnect from the terminal */
 
 #ifdef	TIOCNOTTY
@@ -208,7 +205,8 @@ int main(int argc, char **argv)
 		close(pipefd[1]);
 		while (wait(&waitstat) != p)
 			;
-		read(pipefd[0], &dummy, 1);
+		if (read(pipefd[0], &dummy, 1) < 0)
+			; /* ignore */
 		close(pipefd[0]);
 		close(3);
 		return (0);
