@@ -61,7 +61,7 @@
 #include	"sysconfdir.h"
 #include	"localstatedir.h"
 
-static const char rcsid[]="$Id: ldapaliasd.c,v 1.24 2006/02/07 02:12:53 mrsam Exp $";
+static const char rcsid[]="$Id: ldapaliasd.c,v 1.25 2006/05/28 15:29:51 mrsam Exp $";
 
 static LDAP *my_ldap_fp=0;
 static const char *basedn;
@@ -678,7 +678,9 @@ static void loop(int fd)
 			close(pipea[1]);
 			close(pipeb[1]);
 
-			read(pipeb[0], &buf, 1);
+			if (read(pipeb[0], &buf, 1) < 0)
+				; /* suppress gcc warning */
+
 			close(pipeb[0]);
 			sleep (5);
 			return;
@@ -763,7 +765,9 @@ static void loop(int fd)
 		char c;
 		int waitstat;
 
-		read(pipe_fromchildren, &c, 1);
+		if (read(pipe_fromchildren, &c, 1) < 0)
+			; /* suppress gcc warning */
+
 		close(pipe_fromchildren);
 		while (wait(&waitstat) >= 0)
 			;
@@ -882,7 +886,12 @@ static void check(const char *source, const char *query)
 
 int main(int argc, char **argv)
 {
-	chdir(COURIER_HOME);
+	if (chdir(COURIER_HOME) < 0)
+	{
+		perror(COURIER_HOME);
+		exit(1);
+	}
+
 	libmail_changeuidgid(MAILUID, MAILGID);
 	
 #if HAVE_SYSLOG_H
