@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2001 Double Precision, Inc.
+** Copyright 1998 - 2005 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -86,6 +86,7 @@ time_t ctlfile_getnextattempt(struct ctlfile *);
 #define	COMCTLFILE_ORECEIPIENT	'R'
 #define	COMCTLFILE_DSN		'N'
 #define	COMCTLFILE_ENVID	'e'
+#define	COMCTLFILE_AUTHNAME	'i'
 #define	COMCTLFILE_DSNFORMAT	't'
 #define	COMCTLFILE_EXPIRES	'E'
 #define COMCTLFILE_FAXEXPIRES	'p'
@@ -110,6 +111,8 @@ time_t ctlfile_getnextattempt(struct ctlfile *);
 #define	COMCTLFILE_MSGID	'M'
 #define	COMCTLFILE_SUBMITDELAY	'L'
 #define COMCTLFILE_SECURITY	'U'
+#define COMCTLFILE_MSGSOURCE	'u'
+#define COMCTLFILE_TRACK	'T'
 
 /*
 ** HACK ALERT:  We want to log the last line of SMTP replies,
@@ -122,6 +125,15 @@ time_t ctlfile_getnextattempt(struct ctlfile *);
 
 #define	COMCTLFILE_DELSUCCESS_NOLOG	'Z'
 
+
+/*
+** HACK ALERT, part II: A COMCTLFILE_DELFAIL_NOTRACK is a COMCTLFILE_DELFAIL,
+** but the error is tracked for backscatter purposes.
+*/
+
+#define COMCTLFILE_DELFAIL_NOTRACK	'Y'
+
+
 #define	SMTPREPLY_TYPE(s)	( *(s) == '5' ? COMCTLFILE_DELFAIL: \
 	*(s) == '1' || *(s) == '2' || *(s) == '3' ? COMCTLFILE_DELSUCCESS:\
 	COMCTLFILE_DELDEFERRED)
