@@ -3,12 +3,12 @@
 ** See COPYING for distribution information.
 */
 
-#include "config.h"
+#include "courier_lib_config.h"
 #include "comfax.h"
 #include <stdio.h>
 #include <string.h>
 
-static const char rcsid[]="$Id: comfax.c,v 1.1 2002/03/05 00:20:11 mrsam Exp $";
+static const char rcsid[]="$Id: comfax.c,v 1.2 2004/10/23 15:54:02 mrsam Exp $";
 
 /*
 **   @fax is the domain for the courierfax module.
