@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2003 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -18,6 +18,7 @@ extern "C" {
 time_t config_readtime(const char *, time_t);
 
 time_t config_time_queuetime();
+time_t config_time_faxqueuetime();
 time_t config_time_warntime();
 time_t config_time_respawnlo();
 time_t config_time_respawnhi();
@@ -26,6 +27,8 @@ time_t config_time_retryalpha();
 time_t config_time_retrygamma();
 time_t config_time_submitdelay();
 
+time_t config_time_queuefill();
+
 #ifdef	__cplusplus
 } ;
 #endif
