@@ -3,7 +3,7 @@
 ** See COPYING for distribution information.
 */
 
-#include	"config.h"
+#include	"courier_lib_config.h"
 #include	"courier.h"
 #include	"comctlfile.h"
 #include	<sys/types.h>
@@ -11,7 +11,7 @@
 #include	<string.h>
 #include	<errno.h>
 
-static const char rcsid[]="$Id: comsecurity.c,v 1.1 2001/04/15 17:02:39 mrsam Exp $";
+static const char rcsid[]="$Id: comsecurity.c,v 1.2 2004/10/23 15:54:02 mrsam Exp $";
 
 const char *ctlfile_security(struct ctlfile *p)
 {
