@@ -2,7 +2,7 @@
 #define	rwint_h
 
 #if	HAVE_CONFIG_H
-#include	"config.h"
+#include	"courier_lib_config.h"
 #endif
 
 #include	"courier.h"
