@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2002 Double Precision, Inc.
+** Copyright 1998 - 2005 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -17,7 +17,6 @@
 #include	"rfc2045/rfc2045charset.h"
 #include	"rfc822/rfc822.h"
 #include	"numlib/numlib.h"
-#include	"authlib/auth.h"
 #include	<stdlib.h>
 #include	<string.h>
 #if	HAVE_UNISTD_H
@@ -173,26 +172,49 @@ struct moduledel *p;
 
 		if (pid == 0)
 		{
-		char	*args[7]={"submit",
-			"-delay=0",
-			NAME,
-			"dns; localhost (localhost [127.0.0.1])",
-			"ftp://ftp.isi.edu/in-notes/rfc1894.txt", 0};
+			char	*args[10];
 
 			/* Arguments to submit to initialize message
 			** metadata */
 
-		struct	ctlfile ctf;
-		int	rc;
-		int	isdeferred=strcmp(p->host, "deferred") == 0;
+			struct	ctlfile ctf;
+			int	rc;
+			int	isdeferred=strcmp(p->host, "deferred") == 0;
+
+			const char *sec_level_orig;
+			char *envp[4];
+			int nenvp=0;
+			int i;
+			int argc;
+
+			char msgsource[80];
 
-		const char *sec_level_orig;
-		char *envp[4];
-		int nenvp=0;
 
 			if (ctlfile_openi(p->inum, &ctf, 0))
 				clog_msg_errno();
 
+
+			argc=0;
+
+
+			args[argc++]="submit";
+			args[argc++]="-delay=0";
+
+			strcpy(msgsource, "-src=");
+
+			if ((i=ctlfile_searchfirst(&ctf,
+						   COMCTLFILE_MSGSOURCE)) >= 0)
+			{
+				strncat(msgsource, ctf.lines[i]+1, 20);
+				strcat(msgsource, "/");
+			}
+			strcat(msgsource, "dsn");
+			args[argc++]=msgsource;
+			args[argc++]="dsn";
+			args[argc++]="dns; localhost (localhost [127.0.0.1])";
+			args[argc++]="ftp://ftp.isi.edu/in-notes/rfc1894.txt";
+			args[argc++]=NULL;
+
 			sec_level_orig=ctlfile_security(&ctf);
 			if (sec_level_orig && *sec_level_orig)
 			{
