@@ -41,7 +41,7 @@
 #include	<courierauth.h>
 #include	<courierauthsasl.h>
 
-static const char rcsid[]="$Id: courieresmtpd.c,v 1.51 2005/12/13 03:00:54 mrsam Exp $";
+static const char rcsid[]="$Id: courieresmtpd.c,v 1.52 2006/07/07 23:17:18 mrsam Exp $";
 
 static char helobuf[256];
 static char authuserbuf[256];
@@ -153,6 +153,10 @@ const char *p;
 				*p='_';
 	}
 
+        putenv(strcat(strcpy(courier_malloc(sizeof("ESMTPHELO=") +
+					    strlen(helobuf)),
+			     "ESMTPHELO="), helobuf));
+
 	if (!extended)
 	{
 		addiovec("250 ", 4);
@@ -314,6 +318,11 @@ char	*buf;
                 {
                         if (*identbuf)  strcat(identbuf, ", ");
                         strcat(strcat(identbuf, "AUTH: "), authuserbuf);
+			putenv(strcat(
+				 strcpy(
+				   courier_malloc(sizeof("SENDERAUTH=") +
+						  strlen(authuserbuf)),
+				   "SENDERAUTH="), authuserbuf));
 		}
 
 		if (tls)
