@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2004 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -35,7 +35,7 @@
 
 #define DEFAULTNAME	"alias@"
 
-static const char rcsid[]="$Id: local.c,v 1.23 2004/10/24 02:01:55 mrsam Exp $";
+static const char rcsid[]="$Id: local.c,v 1.25 2006/08/12 02:06:35 mrsam Exp $";
 
 extern char *local_dotcourier(const char *, const char *, const char **);
 
@@ -698,12 +698,12 @@ const char *quota;
 		if (fd < 0)
 			open("/dev/null", O_RDONLY);
 		else
-			dup(fd);
-		close(fd);
-		close(1);
-		dup(p[1]);
-		close(2);
-		dup(p[1]);
+		{
+			dup2(fd, 0);
+			close(fd);
+		}
+		dup2(p[1], 1);
+		dup2(p[1], 2);
 		close(p[0]);
 		close(p[1]);
 
