@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -158,11 +158,9 @@ struct moduledel *p;
 
 			close(pipe1[0]);
 			close(pipe2[0]);
-			close(2);
-			dup(pipe2[1]);
+			dup2(pipe2[1], 2);
 			close(pipe2[1]);
-			close(1);
-			dup(pipe1[1]);
+			dup2(pipe1[1], 1);
 			close(pipe1[1]);
 			close(0);
 			if (dup(datfd) != 0)
