@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2004 Double Precision, Inc.
+** Copyright 2000-2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -360,14 +360,11 @@ const char *sec;
 
 		close(fp);
 		close(pipefd[1]);
-		close(0);
-		dup(pipefd[0]);
+		dup2(pipefd[0], 0);
 		close(pipefd[0]);
 		close(pipefd2[0]);
-		close(1);
-		close(2);
-		dup(pipefd2[1]);
-		dup(pipefd2[1]);
+		dup2(pipefd2[1], 1);
+		dup2(pipefd2[1], 2);
 		close(pipefd2[1]);
 
 		argenv=getenv("UUXFLAGS");
