@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2004 Double Precision, Inc.
+** Copyright 1998 - 2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -25,7 +25,7 @@
 #define EX_NOPERM       77
 #endif
 
-static const char rcsid[]="$Id: sendmail-esmtpd-wrapper.c,v 1.8 2004/10/23 15:54:01 mrsam Exp $";
+static const char rcsid[]="$Id: sendmail-esmtpd-wrapper.c,v 1.9 2006/05/28 15:29:51 mrsam Exp $";
 
 /*
 	-bs flag to sendmail should invoke courieresmtpd, however courieresmtpd
@@ -80,16 +80,14 @@ pid_t	pid;
 	}
 	if (pid == 0)
 	{
-		close(1);
-		dup(pipefd[1]);
+		dup2(pipefd[1], 1);
 		close(pipefd[0]);
 		close(pipefd[1]);
 		execl(BINDIR "/addcr", "addcr", (char *)0);
 		perror("exec");
 		exit(EX_TEMPFAIL);
 	}
-	close(0);
-	dup(pipefd[0]);
+	dup2(pipefd[0], 0);
 	close(pipefd[0]);
 	close(pipefd[1]);
 	close(2); open("/dev/null", O_WRONLY); /* Pine temper tantrum */
