@@ -2,9 +2,9 @@
 #
 # TITLE: Webmail
 #
-# $Id: admin-47webmail.pl,v 1.4 2003/07/06 16:16:37 mrsam Exp $
+# $Id: admin-47webmail.pl,v 1.6 2005/02/16 02:42:49 mrsam Exp $
 #
-# Copyright 2001 Double Precision, Inc.  See COPYING for
+# Copyright 2001-2005 Double Precision, Inc.  See COPYING for
 # distribution information.
 
 
@@ -52,33 +52,53 @@ if ($cgi->param("submit"))
 	DeleteConfigFile("autoresponsequota");
     }
 
+    my $authdaemonvars=ReadEnvVarConfigFile("authdaemonrc");
+ 
+    my %defaultoptions;
+
+    foreach (split(/,/, $$authdaemonvars{'DEFAULTOPTIONS'}))
+    {
+	$defaultoptions{$1}=$2 if /(.*)=(.*)/;
+    }
+
     if ($cgi->param("NOCHANGINGFROM"))
     {
-	DeleteConfigFile("nochangingfrom");
+	delete $defaultoptions{"wbnochangingfrom"};
     }
     else
     {
-	SaveOneLineConfigFile("nochangingfrom", "");
+	$defaultoptions{"wbnochangingfrom"}=1;
     }
 
     if ($cgi->param("USEXSENDER"))
     {
-	SaveOneLineConfigFile("usexsender", "");
+	$defaultoptions{"wbusexsender"}=1;
     }
     else
     {
-	DeleteConfigFile("usexsender");
+	delete $defaultoptions{"wbusexsender"};
     }
 
     if ($cgi->param("IMAGES"))
     {
-	DeleteConfigFile("noimages");
+	delete $defaultoptions{"wbnoimages"};
     }
     else
     {
-	SaveOneLineConfigFile("noimages", "");
+	$defaultoptions{"wbnoimages"}=1;
     }
 
+    my $v="";
+
+    foreach (keys %defaultoptions)
+    {
+	$v .= "," if $v;
+	$v .= "$_=$defaultoptions{$_}";
+    }
+
+    ReplaceEnvVarConfigFile("authdaemonrc", "DEFAULTOPTIONS", $v);
+    changed("$authdaemond stop; $authdaemond start");
+
     my @logindomainlist=split(/\n/, $cgi->param("logindomainlist"));
 
     grep { s/\s+$//; s/^\s+//; } @logindomainlist;
@@ -103,7 +123,7 @@ if ($cgi->param("submit"))
     {
 	DeleteConfigFile("calendarmode");
     }
-    changed("test -x ${libexecdir}/courier/pcpd || exit 0; if test \"\`cat ${sysconfdir}/calendarmode 2>/dev/null\`\" = 'net' ; then $libexecdir/courier/pcpd start ; else $libexecdir/courier/pcpd stop ; fi");
+    changed("test -x ${libexecdir}/courier/pcpd || exit 0; ${sbindir}/webmaild stop; ${sbindir}/webmaild start");
     $errmsg="\@SAVED\@";
 }
 
@@ -135,14 +155,26 @@ sub cexists {
     return undef;
 }
 
+
+my $authdaemonvars=ReadEnvVarConfigFile("authdaemonrc");
+ 
+my %defaultoptions;
+
+foreach (split(/,/, $$authdaemonvars{'DEFAULTOPTIONS'}))
+{
+    $defaultoptions{$1}=$2 if /(.*)=(.*)/;
+}
+
+
+
 my $maildirfilterconfig="<input type=\"checkbox\" name=\"maildirfilterconfig\""
     . ( cexists("maildirfilterconfig") ? " checked=\"checked\"":"") . " />";
 my $NOCHANGINGFROM="<input type=\"checkbox\" name=\"NOCHANGINGFROM\""
-    . ( cexists("nochangingfrom") ? "":" checked=\"checked\"") . " />";
+    . ( $defaultoptions{"wbnochangingfrom"} ? "":" checked=\"checked\"") . " />";
 my $USEXSENDER="<input type=\"checkbox\" name=\"USEXSENDER\""
-    . ( cexists("usexsender") ? " checked=\"checked\"":"") . " />";
+    . ( $defaultoptions{"wbusexsender"} ? " checked=\"checked\"":"") . " />";
 my $IMAGES="<input type=\"checkbox\" name=\"IMAGES\""
-    . ( cexists("noimages") ? "":" checked=\"checked\"") . " />";
+    . ( $defaultoptions{"wbnoimages"} ? "":" checked=\"checked\"") . " />";
 my $logindomainlist="";
 
 my $fh=OpenConfigFile("logindomainlist");
