@@ -1,9 +1,9 @@
 /*
-** Copyright 2001-2003 Double Precision, Inc.  See COPYING for
+** Copyright 2001-2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: gpg.c,v 1.10 2005/11/23 01:08:27 mrsam Exp $";
+static const char rcsid[]="$Id: gpg.c,v 1.11 2006/05/28 15:29:52 mrsam Exp $";
 
 #include "config.h"
 #include <stdio.h>
@@ -1698,7 +1698,8 @@ static int dodecrypt(const char *, const char *,
 
 static void write_temp_fp(const char *p, size_t n, void *vp)
 {
-	fwrite(p, n, 1, (FILE *)vp);
+	if (fwrite(p, n, 1, (FILE *)vp) != 1)
+		; /* ignored */
 }
 
 static int decrypt(const char *gpghome,
@@ -1927,7 +1928,11 @@ static int dumpdecrypt(const char *c, size_t n, void *vp)
 {
 	FILE *fp=(FILE *)vp;
 
-	fwrite(c, n, 1, fp);
+	if (n == 0)
+		return 0;
+
+	if (fwrite(c, n, 1, fp) != 1)
+		return -1;
 	return (0);
 }
 
