@@ -3,7 +3,7 @@
 ** distribution information.
 */
 
-static const char rcsid[]="$Id: mimegpgstack.c,v 1.1 2001/03/15 04:20:35 mrsam Exp $";
+static const char rcsid[]="$Id: mimegpgstack.c,v 1.2 2003/06/02 15:51:23 mrsam Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -12,29 +12,26 @@ static const char rcsid[]="$Id: mimegpgstack.c,v 1.1 2001/03/15 04:20:35 mrsam E
 #include <ctype.h>
 #include "mimegpgstack.h"
 
-void push_mimestack(struct mimestack **s, const char *b)
+int libmail_mimestack_push(struct mimestack **s, const char *b)
 {
 	struct mimestack *ss=(struct mimestack *)
 		malloc(sizeof(**s));
 
 	if (!ss)
-	{
-		perror("malloc");
-		exit(1);
-	}
+		return -1;
 
 	if ((ss->boundary=strdup(b)) == NULL)
 	{
 		free(ss);
-		perror("strdup");
-		exit(1);
+		return -1;
 	}
 
 	ss->next= *s;
 	*s=ss;
+	return 0;
 }
 
-void pop_mimestack(struct mimestack **p)
+void libmail_mimestack_pop(struct mimestack **p)
 {
 	struct mimestack *pp= *p;
 
@@ -46,18 +43,18 @@ void pop_mimestack(struct mimestack **p)
 	}
 }
 
-void pop_mimestack_to(struct mimestack **p, struct mimestack *s)
+void libmail_mimestack_pop_to(struct mimestack **p, struct mimestack *s)
 {
 	while (*p)
 	{
 		int last=strcmp( (*p)->boundary, s->boundary) == 0;
-		pop_mimestack(p);
+		libmail_mimestack_pop(p);
 		if (last)
 			break;
 	}
 }
 
-struct mimestack *search_mimestack(struct mimestack *p, const char *c)
+struct mimestack *libmail_mimestack_search(struct mimestack *p, const char *c)
 {
 	int l=strlen(c);
 
