@@ -59,7 +59,7 @@
 #include	"imapwrite.h"
 #include	"imapd.h"
 
-static const char rcsid[]="$Id: imapscanclient.c,v 1.44 2004/04/21 01:09:15 mrsam Exp $";
+static const char rcsid[]="$Id: imapscanclient.c,v 1.45 2004/07/19 23:54:14 mrsam Exp $";
 
 static int do_imapscan_maildir2(struct imapscaninfo *, const char *,
 				int, int, struct uidplus_info *);
@@ -222,11 +222,24 @@ char	*p=malloc(strlen(dir)+strlen(new_or_cur)+2);
 static int fnamcmp(const char *a, const char *b)
 {
 	long ai, bi;
+	char ca, cb;
+
 	ai = atol(a);
 	bi = atol(b);
 	if(ai - bi)
 		return ai - bi;
-	return strcmp(a, b);
+
+	do
+	{
+		ca= *a++;
+		cb= *b++;
+
+		if (ca == ':') ca=0;
+		if (cb == ':') cb=0;
+	} while (ca && cb && ca == cb);
+
+
+	return ( (int)(unsigned char)ca - (int)(unsigned char)cb);
 }
 
 static int sort_by_filename(struct tempinfo **a, struct tempinfo **b)
