@@ -65,9 +65,9 @@
 #include	"maildir/maildirnewshared.h"
 #include	"maildir/maildirinfo.h"
 #include	"unicode/unicode.h"
-#include	"authlib/auth.h"
+#include	"courierauth.h"
 
-static const char rcsid[]="$Id: mailboxlist.c,v 1.18 2004/05/25 02:08:40 mrsam Exp $";
+static const char rcsid[]="$Id: mailboxlist.c,v 1.19 2004/10/21 00:45:35 mrsam Exp $";
 
 static const char hierchs[]={HIERCH, 0};
 
@@ -97,7 +97,7 @@ const char *maildir_shared_index_file()
 
 		if (p && *p)
 		{
-			const char *q=authgetoptionenv("sharedgroup");
+			const char *q=auth_getoptionenv("sharedgroup");
 
 			if (!q) q="";
 
