@@ -44,7 +44,6 @@
 #include	"mailboxlist.h"
 #include	"thread.h"
 #include	"outbox.h"
-#include	"authlib/authmod.h"
 
 #include	"imapwrite.h"
 #include	"imaptoken.h"
@@ -67,7 +66,7 @@
 
 #define SMAP_BUFSIZ 8192
 
-static const char rcsid[]="$Id: smap.c,v 1.23 2004/06/13 19:20:04 mrsam Exp $";
+static const char rcsid[]="$Id: smap.c,v 1.27 2005/11/21 23:36:47 mrsam Exp $";
 #define SHARED "shared"
 
 #define LIST_FOLDER 1
@@ -366,28 +365,21 @@ static void list_callback(const char *f, void *vp)
 
 	if (maildir_acl_read(&l, utf8->homedir, strchr(f, '.')) == 0)
 	{
-		const char *owner_array[3];
-		maildir_aclt aa;
-		char *o;
+		char *myrights;
+		char *owner=malloc(sizeof("user=")+strlen(utf8->owner));
 
-		owner_array[0]=o=malloc(sizeof("user=")+
-					strlen(getenv("AUTHENTICATED")));
-		if (o == NULL)
+		if (!owner)
 			write_error_exit(0);
-		strcat(strcpy(o, "user="), getenv("AUTHENTICATED"));
-		owner_array[1]= strcmp(utf8->owner, getenv("AUTHENTICATED"))
-			? NULL:"owner";
-		owner_array[2]=NULL;
 
-		if (maildir_acl_compute_array(&aa, &l, owner_array) == 0)
-		{
-			if (strchr(maildir_aclt_ascstr(&aa),
-				   ACL_LOOKUP[0]) != NULL)
-				(*utf8->callback_func)(f, fn,
-						       utf8->callback_arg);
-			maildir_aclt_destroy(&aa);
-		}
-		free(o);
+		strcat(strcpy(owner, "user="), utf8->owner);
+		myrights=compute_myrights(&l, owner);
+		free(owner);
+
+		if (myrights && strchr(myrights, ACL_LOOKUP[0]) != NULL)
+			(*utf8->callback_func)(f, fn, utf8->callback_arg);
+		if (myrights)
+			free(myrights);
+
 		maildir_aclt_list_destroy(&l);
 	}
 	maildir_smapfn_free(fn);
@@ -2334,7 +2326,7 @@ static void fixnewfilename(char *p)
 
 	q=strrchr(strrchr(p, '/'), MDIRSEP[0]);
 
-	if (strcmp(q, ":2,") == 0)
+	if (strcmp(q, MDIRSEP "2,") == 0)
 	{
 		*q=0;
 		memcpy(strrchr(p, '/')-3, "new", 3);
@@ -3136,7 +3128,7 @@ static int dosetdeleteacl(void *cb_arg, int dodelete)
 			aclminimum(err_failedrights);
 			writes("\n");
 		}
-		writes("+ERR ACL update failed\n");
+		writes("-ERR ACL update failed\n");
 		maildir_aclt_list_destroy(&aclt_list);
 		return 0;
 	}
@@ -4144,6 +4136,7 @@ void smap()
 				if (q) free(q);
 				maildir_info_destroy(&minfo);
 				accessdenied(ACL_READ);
+				maildir_info_destroy(&minfo);
 				continue;
 			}
 			current_mailbox_acl=q;
@@ -4156,8 +4149,10 @@ void smap()
 					" in maildir_name2dir(%s,%s)\n",
 					minfo.homedir,
 					minfo.maildir);
+				maildir_info_destroy(&minfo);
 				continue;
 			}
+			maildir_info_destroy(&minfo);
 
 			snapshot_select(snapshot != NULL);
 
