@@ -47,7 +47,7 @@
 #define	EX_NOPERM	77
 #endif
 
-static const char rcsid[]="$Id: deliverquota.c,v 1.21 2003/01/20 13:47:19 mrsam Exp $";
+static const char rcsid[]="$Id: deliverquota.c,v 1.22 2005/01/30 14:50:37 mrsam Exp $";
 
 static long deliver(int fdin, const char *dir, long s,
 		    int auto_create, int quota_warn_percent, const char *pfix,
@@ -131,7 +131,11 @@ static long deliver(int fdin, const char *dir, long s,
 			{
 				unlink(createInfo.tmpname);
 				printf("Mail quota exceeded.\n");
+#if HAVE_COURIER
+				exit(EX_TEMPFAIL);
+#else
 				exit(EX_NOPERM);
+#endif
 			}
 			maildir_quota_add_end(&info, ss-s, 1);
 		}
