@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2003 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -45,7 +45,7 @@
 
 #define exit(_a_) _exit(_a_)
 
-static const char rcsid[]="$Id: maildircache.c,v 1.8 2004/04/18 15:54:39 mrsam Exp $";
+static const char rcsid[]="$Id: maildircache.c,v 1.9 2006/05/28 15:29:52 mrsam Exp $";
 
 static const char * const *authvars;
 static char **authvals;
@@ -319,7 +319,9 @@ void maildir_cache_cancel()
 {
 	if (childproc > 0)
 	{
-		write(childpipe, "CANCELLED\n", 10); 
+		if (write(childpipe, "CANCELLED\n", 10) < 0)
+			perror("write");
+
 		close(childpipe);
 	}
 }
