@@ -35,7 +35,7 @@
 #include	<unistd.h>
 #endif
 
-static const char rcsid[]="$Id: maildirfilter.c,v 1.26 2006/05/13 02:54:23 mrsam Exp $";
+static const char rcsid[]="$Id: maildirfilter.c,v 1.27 2006/07/01 00:37:09 mrsam Exp $";
 
 struct maildirfilterrule *maildir_filter_appendrule(struct maildirfilter *r,
 					const char *name,
@@ -98,6 +98,15 @@ const char *c;
 			*c == '`')
 			return (-1);
 
+	/* rule name: may not already exist */
+	*errcode=MF_ERR_EXISTS;
+	
+	struct maildirfilterrule *pom;
+	for (pom=r->first; pom->next; pom=pom->next) {
+	    if (p!=pom && !strcmp(name, pom->rulename))
+		return (-1);
+	}
+
 	/* rule type: we must know what it is */
 
 	switch (type)	{
