@@ -2,17 +2,19 @@
 #define	rfc1035_res_h
 
 /*
-** Copyright 1998 - 2000 Double Precision, Inc.
+** Copyright 1998 - 2002 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
 #include	"rfc1035.h"
+#include	"random128/random128.h"
+#include	"md5/md5.h"
 #include	<sys/types.h>
 #include	<sys/socket.h>
 #include	<netinet/in.h>
 #include	<arpa/inet.h>
 
-static const char rfc1035_res_rcsid[]="$Id: rfc1035_res.h,v 1.4 2000/05/21 20:27:56 mrsam Exp $";
+static const char rfc1035_res_rcsid[]="$Id: rfc1035_res.h,v 1.5 2002/07/01 03:17:05 mrsam Exp $";
 
 #ifdef  __cplusplus
 extern "C" {
@@ -32,7 +34,10 @@ struct rfc1035_res {
 	unsigned rfc1035_good_ns;
 	unsigned rfc1035_timeout_initial;	/* Initial timeout */
 	unsigned rfc1035_timeout_backoff;	/* Maximum exponential backoff */
-	unsigned id;
+
+	random128binbuf randseed;
+	MD5_DIGEST	randbuf;
+	unsigned randptr;
 	} ;
 
 extern struct rfc1035_res rfc1035_default_resolver;
