@@ -1,5 +1,5 @@
 /*
-** Copyright 2004 Double Precision, Inc.
+** Copyright 2004-2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -24,7 +24,7 @@
 #endif
 #endif
 
-static const char rcsid[]="$Id: spf.c,v 1.5 2004/08/24 00:43:30 mrsam Exp $";
+static const char rcsid[]="$Id: spf.c,v 1.8 2006/04/12 23:00:26 mrsam Exp $";
 
 static void set_err_msg(char *errmsg_buf,
 			size_t errmsg_buf_size,
@@ -165,7 +165,7 @@ char rfc1035_spf_gettxt(const char *current_domain,
 	if (rfc1035_resolve_cname(&rfc1035_default_resolver,
 				  RFC1035_RESOLVE_RECURSIVE, namebuf,
 				  RFC1035_TYPE_TXT, RFC1035_CLASS_IN,
-				  &reply) < 0 ||
+				  &reply, 0) < 0 ||
 	    reply == 0 ||
 	    (n=rfc1035_replysearch_an(&rfc1035_default_resolver,
 				      reply, namebuf, RFC1035_TYPE_TXT,
@@ -473,8 +473,13 @@ static void get_domain_pfix(struct rfc1035_spf_info *info,
 {
 	*pfix_ptr=sizeof(RFC1035_ADDR)*8;
 
-	if (*start == 0)
+	if (*start == 0 || *start == '/')
+	{
 		*domain_ptr=strdup(strrchr(info->mailfrom, '@')+1);
+
+		if (*start == '/')
+			*pfix_ptr=get_dual_cidr_length(start);
+	}
 	else
 	{
 		char *p;
@@ -771,7 +776,7 @@ static char mechanism(const char *name,
 
 		free(domain_spec);
 
-		if (rc < 0)
+		if (rc != 0)
 		{
 			set_err_msg(info->errmsg_buf, info->errmsg_buf_size,
 				    "IP address lookup failed.\n");
@@ -952,7 +957,7 @@ static void setexp(const char *exp,
 	if (rfc1035_resolve_cname(&rfc1035_default_resolver,
 				  RFC1035_RESOLVE_RECURSIVE, namebuf,
 				  RFC1035_TYPE_TXT, RFC1035_CLASS_IN,
-				  &reply) < 0 ||
+				  &reply, 0) < 0 ||
 	    reply == 0 ||
 	    (n=rfc1035_replysearch_an(&rfc1035_default_resolver,
 				      reply, namebuf, RFC1035_TYPE_TXT,
