@@ -4,7 +4,7 @@
 */
 
 /*
-** $Id: rfc2045.h,v 1.32 2004/06/06 16:04:34 mrsam Exp $
+** $Id: rfc2045.h,v 1.33 2004/06/27 02:28:22 mrsam Exp $
 */
 #ifndef	rfc2045_h
 #define	rfc2045_h
@@ -165,7 +165,7 @@ int rfc2045_rewrite_func(struct rfc2045 *p, int,
 int rfc2045_try_boundary(struct rfc2045 *, int, const char *);
 char *rfc2045_mk_boundary(struct rfc2045 *, int);
 const char *rfc2045_getattr(const struct rfc2045attr *, const char *);
-void rfc2045_setattr(struct rfc2045attr **, const char *, const char *);
+int rfc2045_attrset(struct rfc2045attr **, const char *, const char *);
 
 /* MIME content base/location */
 
