@@ -2,7 +2,7 @@
 #define	sconnect_h
 
 #if	HAVE_CONFIG_H
-#include	"soxwrap/config.h"
+#include	"soxwrap/soxwrap_config.h"
 #endif
 
 #if TIME_WITH_SYS_TIME
@@ -23,7 +23,7 @@
 ** See COPYING for distribution information.
 */
 
-static const char sconnect_h_rcsid[]="$Id: sconnect.h,v 1.2 2002/02/21 00:37:01 mrsam Exp $";
+static const char sconnect_h_rcsid[]="$Id: sconnect.h,v 1.3 2004/07/24 03:36:53 mrsam Exp $";
 
 #ifdef  __cplusplus
 extern "C"
