@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2002 Double Precision, Inc.
+** Copyright 2000-2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 #include	"config.h"
@@ -493,7 +493,7 @@ SSL_CTX *tls_create(int isserver, const struct tls_info *info)
 				FILE *fp;
 
 				p=strrchr(de->d_name, '.');
-				if (!p[0] || !p[1])
+				if (!p || !p[1])
 					continue;
 				while (*++p)
 				{
@@ -619,7 +619,7 @@ static int cache_add(SSL *ssl, SSL_SESSION *sess)
 		sizeof(session_id_len)+session_id_len;
 
 	i2d_SSL_SESSION(sess, &ucp);
-	if (tls_cache_add(info->tlscache, buffer,
+	if (tls_cache_add(info->tlscache, (char *)buffer,
 			  (size_t)(sizeof(timeout) +
 				   sizeof(session_id_len) +
 				   session_id_len + sess_len)))
