@@ -1,5 +1,5 @@
 /*
-** Copyright 2000-2003 Double Precision, Inc.
+** Copyright 2000-2006 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 #include	"config.h"
@@ -65,7 +65,7 @@
 #endif
 #include	<locale.h>
 
-static const char rcsid[]="$Id: starttls.c,v 1.34 2003/09/01 19:30:23 mrsam Exp $";
+static const char rcsid[]="$Id: starttls.c,v 1.35 2006/05/28 15:29:52 mrsam Exp $";
 
 /* Command-line options: */
 const char *clienthost=0;
@@ -292,8 +292,8 @@ static void dump_x509(X509 *x509, FILE *printx509_fp)
 		if (printx509_fp)
 		{
 			fprintf(printx509_fp, "   %s=", obj_name);
-			fwrite(ddata, dlen, 1, printx509_fp);
-			fprintf(printx509_fp, "\n");
+			if (fwrite(ddata, dlen, 1, printx509_fp) == 1)
+				fprintf(printx509_fp, "\n");
 		}
 	}
 	if (printx509_fp)
@@ -443,10 +443,8 @@ int	streampipe[2];
 	int n;
 
 		close(fd);	/* Child process doesn't need it */
-		close(0);
-		dup(streampipe[1]);
-		close(1);
-		dup(streampipe[1]);
+		dup2(streampipe[1], 0);
+		dup2(streampipe[1], 1);
 		close(streampipe[0]);
 		close(streampipe[1]);
 
@@ -837,8 +835,7 @@ void (*protocol_func)(int)=0;
 
 	if (tcpd)
 	{
-		close(1);
-		dup(2);
+		dup2(2, 1);
 		fd=0;
 	}
 	else if (remotefd)
