@@ -52,7 +52,7 @@
 
 #include	<netdb.h>
 
-static const char rcsid[]="$Id: tcpd.c,v 1.42 2006/01/23 23:22:10 mrsam Exp $";
+static const char rcsid[]="$Id: tcpd.c,v 1.43 2006/05/28 15:29:52 mrsam Exp $";
 
 static const char *accessarg=0;
 static const char *accesslocal=0;
@@ -1192,8 +1192,12 @@ static void accepted(int n, int sockfd, RFC1035_NETADDR *sin, int sinl,
 		if (allowaccess(&addr,0) == 0)
 		{
 			if (denymsgarg) {
-				write(sockfd, denymsgarg, strlen(denymsgarg));
-				write(sockfd, "\n", 1);
+				if (write(sockfd, denymsgarg, strlen(denymsgarg)) < 0 ||
+				    write(sockfd, "\n", 1) < 0)
+				{
+					sox_close(sockfd);
+					_exit(1);
+				}
 			}
 			sox_close(sockfd);
 			_exit(0);
