@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 1999 Double Precision, Inc.
+** Copyright 1998 - 2005 Double Precision, Inc.
 ** See COPYING for distribution information.
 */
 
@@ -7,9 +7,23 @@
 #include	"waitlib.h"
 #endif
 #include	<signal.h>
+#include	<stdio.h>
 
-static const char rcsid[]="$Id: waitlib.c,v 1.3 1999/12/06 13:32:02 mrsam Exp $";
+static const char rcsid[]="$Id: waitlib.c,v 1.4 2005/08/20 13:03:30 mrsam Exp $";
 
+#if	HAVE_SIGPROCMASK
+
+#define HOLD_CHILDREN {\
+	sigset_t ss; sigemptyset(&ss); sigaddset(&ss, SIGCHLD); \
+	sigprocmask(SIG_BLOCK, &ss, NULL);\
+	}
+
+#define RELEASE_CHILDREN {\
+	sigset_t ss; sigemptyset(&ss); sigaddset(&ss, SIGCHLD); \
+	sigprocmask(SIG_UNBLOCK, &ss, NULL);\
+	}
+
+#else
 #if	HAVE_SIGHOLD
 
 #define	HOLD_CHILDREN	sighold(SIGCHLD)
@@ -20,6 +34,7 @@ static const char rcsid[]="$Id: waitlib.c,v 1.3 1999/12/06 13:32:02 mrsam Exp $"
 #define	HOLD_CHILDREN	sigblock(sigmask(SIGCHLD))
 #define	RELEASE_CHILDREN	sigsetmask(0)
 
+#endif
 #endif
 
 #if	USE_WAIT3
