@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2004 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: maildir.c,v 1.85 2004/10/21 01:12:57 mrsam Exp $
+** $Id: maildir.c,v 1.87 2006/05/29 13:31:15 mrsam Exp $
 */
 #include	"config.h"
 #include	<stdio.h>
@@ -2000,7 +2000,9 @@ int	fd;
 	if ((p && p - filename >=
 		sizeof(SENT) + 5 && strncmp(p - (sizeof(SENT) + 5),
 			"/." SENT "/", sizeof(SENT)+2) == 0)
-		|| strncmp(filename, "." SENT "/", sizeof(SENT)+1) == 0)
+		|| strncmp(filename, "." SENT "/", sizeof(SENT)+1) == 0
+		|| strncmp(filename, "./." SENT ".", sizeof(SENT)+3) == 0
+		|| strncmp(filename, "." SENT ".", sizeof(SENT)+1) == 0)
 		is_sent_header=1;
 	if ((p && p - filename >=
 		sizeof(DRAFTS) + 5 && strncmp(p-(sizeof(DRAFTS) + 5),
@@ -2152,7 +2154,8 @@ static void maildir_save_start(const char *folder,
 	  }
 	  if (f != -1) {
 	    struct stat s;
-	    write(f, ".", 1);
+	    if (write(f, ".", 1) != 1)
+		    ; /* ignore */
 	    fsync(f);
 	    if (fstat(f, &s) == 0)
 	      save_time = s.st_mtime;
