@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2005 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: newmsg.c,v 1.57 2005/11/23 02:37:23 mrsam Exp $
+** $Id: newmsg.c,v 1.62 2006/07/30 19:01:42 mrsam Exp $
 */
 #include	"config.h"
 #include	"sqwebmail.h"
@@ -78,7 +78,8 @@ const struct unicode_info *uiptr=unicode_find(sqwebmail_content_charset);
 	       "<td width=\"6\">&nbsp;</td>",
 	       field, label);
 
-	printf("<td><input name=\"%s\" size=\"50\" maxlength=\"512\" value=\"",
+	printf("<td><input type=\"text\" name=\"%s\" size=\"50\" maxlength=\"512\""
+	       " class=\"new-message-header-text\" value=\"",
 		field);
 	if (encoded)
 	{
@@ -114,14 +115,16 @@ static void printsep(const char *c, void *dummy)
 }
 
 static void newmsg_header_rfc822(const char *label, const char *field,
-				 const char *encoded, const char *val)
+				 const char *encoded, const char *val,
+				 int is_readonly)
 {
 	printf("<tr><th align=\"right\"><p class=\"new-message-header\">"
 	       "<span class=\"new-message-header-%s\">%s</span></p></th>"
 	       "<td width=\"6\">&nbsp;</td>",
 	       field, label);
 
-	printf("<td><input name=\"%s\" size=\"50\" maxlength=\"512\" value=\"",
+	printf("<td><input type=\"text\" name=\"%s\" size=\"50\" maxlength=\"512\""
+	       " class=\"new-message-header-text\" value=\"",
 		field);
 	if (encoded)
 	{
@@ -146,7 +149,8 @@ static void newmsg_header_rfc822(const char *label, const char *field,
 	}
 	else if (val)
 		output_attrencoded(val);
-	printf("\" /></td></tr>\n");
+	printf("\"%s /></td></tr>\n",
+		is_readonly ? " readonly=\"readonly\"":"");
 }
 
 static const char *ispreviewmsg()
@@ -178,7 +182,8 @@ void newmsg_hiddenheader(const char *label, const char *value)
 
 static void preview_show_func_s(const char *p, size_t n)
 {
-	fwrite(p, 1, n, stdout);
+	if (fwrite(p, 1, n, stdout) != n)
+		; /* ignore */
 }
 
 void preview_start()
@@ -459,7 +464,8 @@ void newmsg_init(const char *folder, const char *pos)
 	const char	*previewlab=getarg("PREVIEWLAB");
 	const char	*forwardsep=getarg("FORWARDLAB");
 	const char	*savedraft=getarg("SAVEDRAFT");
-	const char	*uploadlab=getarg("ATTACHMENTS");
+	const char	*attachmentslab=getarg("ATTACHMENTS");
+	const char      *uploadlab=getarg("UPLOAD");
 	const char	*replysalutation=getarg("SALUTATION");
 	const char	*checkspellingdone=getarg("SPELLCHECKDONE");
 	const char	*checkspelling=getarg("CHECKSPELLING");
@@ -467,6 +473,10 @@ void newmsg_init(const char *folder, const char *pos)
 	const char	*fromlab=getarg("FROMLAB");
 	const char	*replytolab=getarg("REPLYTOLAB");
 	const char	*addressbooklab=getarg("ADDRESSBOOK");
+	const char	*select1=getarg("SELECT1");
+	const char	*select2=getarg("SELECT2");
+	const char	*text1=getarg("TEXT1");
+	const char	*text2=getarg("TEXT2");
 	char	*draftmessage;
 	char	*draftmessagefilename;
 	const	char *p;
@@ -620,11 +630,12 @@ void newmsg_init(const char *folder, const char *pos)
 	printf("<table width=\"100%%\" border=\"0\" cellspacing=\"0\" cellpadding=\"4\" class=\"new-message-box\"><tr><td>\n");
 
 	printf("<table border=\"0\" width=\"100%%\">\n");
-	if (auth_getoptionenvint("wbnochangingfrom") == 0)
+	int wbnochangingfrom=auth_getoptionenvint("wbnochangingfrom");
+	if (wbnochangingfrom < 2)
 		newmsg_header_rfc822(fromlab, "headerfrom", curfrom,
 			*cgi("from") ? cgi("from"):
 			pref_from && *pref_from ? pref_from:
-			login_fromhdr());
+			login_fromhdr(), wbnochangingfrom ? 1:0);
 
 	printf("<tr valign=\"middle\"><th align=\"right\">"
 	       "<p class=\"new-message-header\">"
@@ -634,9 +645,9 @@ void newmsg_init(const char *folder, const char *pos)
 
 	printf("<td valign=\"middle\">");
 	printf("<table border=\"0\" cellpadding=\"0\" cellspacing=\"4\">");
-	printf("<tr valign=\"middle\"><td><select name=\"nick\" size=\"4\" multiple=\"multiple\">\n");
+	printf("<tr valign=\"middle\"><td>%s\n", select1);
 	ab_listselect();
-	printf("</select></td><td width=\"100%%\">");
+	printf("%s</td><td width=\"100%%\">", select2);
 	printf("<input type=\"submit\" name=\"addressbook_to\" value=\"%s\" />",
 			tolab);
 	printf("<input type=\"submit\" name=\"addressbook_cc\" value=\"%s\" />",
@@ -646,11 +657,11 @@ void newmsg_init(const char *folder, const char *pos)
 	printf("</td></tr></table>");
 
 	printf("</td></tr>\n");
-	newmsg_header_rfc822(tolab, "headerto", curto, cgi("to"));
-	newmsg_header_rfc822(cclab, "headercc", curcc, cgi("cc"));
-	newmsg_header_rfc822(bcclab, "headerbcc", curbcc, cgi("bcc"));
+	newmsg_header_rfc822(tolab, "headerto", curto, cgi("to"), 0);
+	newmsg_header_rfc822(cclab, "headercc", curcc, cgi("cc"), 0);
+	newmsg_header_rfc822(bcclab, "headerbcc", curbcc, cgi("bcc"), 0);
 	newmsg_header_rfc822(replytolab, "headerreply-to",
-			     curreplyto, cgi("replyto"));
+			     curreplyto, cgi("replyto"), 0);
 	newmsg_header(subjectlab, "headersubject",
 		      cursubj, cgi("subject"));
 
@@ -668,12 +679,13 @@ void newmsg_init(const char *folder, const char *pos)
 	       "<p class=\"new-message-header\">"
 	       "<span class=\"new-message-header-message\">"
 	       "%s</span></p></th><td width=\"6\">&nbsp;</td>"
-	       "<td><select name=\"textformat\"><option value=\"plain\" %s>%s"
-	       "<option value=\"wiki\" %s>%s</select>"
+	       "<td><select name=\"textformat\">"
+	       "<option value=\"plain\" %s>%s</option>"
+	       "<option value=\"wiki\" %s>%s</option></select>"
 
 	       "<small>(<a href='%s/wikifmt.html' target='_blank'>%s</a>)</small>"
 	       "</td></tr>"
-	       "<th valign=\"top\" align=\"right\">"
+	       "<tr><th valign=\"top\" align=\"right\">"
 	       "<p class=\"new-message-header\">"
 	       "<span class=\"new-message-header-message\">"
 	       "%s</span></p></th><td width=\"6\">&nbsp;</td>",
@@ -685,8 +697,7 @@ void newmsg_init(const char *folder, const char *pos)
 	       get_imageurl(), getarg("FMTHELP"),
 	       messagelab);
 
-	printf("<td><textarea name=\"message\" cols=\"%d\" rows=\"15\" wrap=\"soft\">",
-		MYLINESIZE);
+	printf("<td>%s\n", text1);
 
 	if (fp)
 	{
@@ -699,8 +710,14 @@ void newmsg_init(const char *folder, const char *pos)
 		{
 		char	buf[256];
 		int	n;
+		struct stat stat_buf;
+		unsigned long filesize=0;
+
+			if (stat(SIGNATURE, &stat_buf) == 0)
+				filesize=stat_buf.st_size;
+			if (filesize > 0)
+				printf("\n\n");
 
-			printf("\n\n");
 			while ((n=fread(buf, 1, sizeof(buf)-1, fp)) > 0)
 			{
 				buf[n]=0;
@@ -710,7 +727,7 @@ void newmsg_init(const char *folder, const char *pos)
 			fp=NULL;
 		}
 	}
-	printf("</textarea><br />\n");
+	printf("%s\n", text2);
 
 	if (draftmessage && *draftmessage)
 	{
@@ -722,10 +739,12 @@ void newmsg_init(const char *folder, const char *pos)
 	if (draftmessage)	free(draftmessage);
 	printf("</td></tr>\n");
 
-	printf("<tr><td><p>&nbsp;</p></td><td>&nbsp;</td><td><input type=\"submit\" name=\"doattachments\" value=\"");
-
-	printf(uploadlab, attachcnt);
-	printf("\" /></td></tr>");
+	printf("<tr><th valign=\"top\" align=\"right\">"
+	       "<p class=\"new-message-header\">"
+	       "<span class=\"new-message-header-message\">"
+		"%s</span></p></th><td>&nbsp;</td>"
+		"<td>%d&nbsp;&nbsp;<input type=\"submit\" name=\"doattachments\" value=\"%s\" /></td></tr>",
+		attachmentslab, attachcnt, uploadlab);
 
 	printf("<tr><td colspan=\"2\" align=\"right\"><input type=\"checkbox\" "
 	       "name=\"fcc\" id=\"fcc\"%s /></td><td><label for=\"fcc\">%s</label></td></tr>\n",
@@ -823,6 +842,8 @@ void sendmsg_done()
 {
 	if ( *cgi("pos"))
 		http_redirect_argss("&form=readmsg&pos=%s", cgi("pos"), "");
+	else if (*cgi("sendmsg"))
+		http_redirect_argss("&form=folders&foldermsg=sent", "", "");
 	else
 		http_redirect_argss("&form=folders", "", "");
 }
@@ -912,17 +933,16 @@ int dsn;
 
 		if (!tmpfile)
 		{
-			fwrite((char*)nofile, 1, sizeof(nofile)-1, stderr);
+			if (fwrite((char*)nofile, 1, sizeof(nofile)-1, stderr))
+				; /* ignore */
 			_exit(1);
 		}
 
 		close(0);
 
 		fd=maildir_safeopen(tmpfile, O_RDONLY, 0);
-		close(1);
-		close(2);
-		dup(pipefd1[1]);
-		dup(pipefd1[1]);
+		dup2(pipefd1[1], 1);
+		dup2(pipefd1[1], 2);
 		close(pipefd1[0]);
 		close(pipefd1[1]);
 
@@ -938,7 +958,8 @@ int dsn;
 				sqwebmail_mailboxid, NULL);
 		}
 			
-		fwrite(noexec, 1, sizeof(noexec)-1, stderr);
+		if (fwrite(noexec, 1, sizeof(noexec)-1, stderr))
+			; /* ignore */
 		_exit(1);
 	}
 	close(pipefd1[1]);
