@@ -1,11 +1,11 @@
 /*
-** Copyright 1998 - 2004 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2005 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
 
 /*
-** $Id: newmsg_create.c,v 1.53 2004/05/23 14:28:24 mrsam Exp $
+** $Id: newmsg_create.c,v 1.58 2005/11/20 00:04:51 mrsam Exp $
 */
 #include	"config.h"
 #include	"cgi/cgi.h"
@@ -25,10 +25,12 @@
 #include	"rfc2045/rfc2646.h"
 #include	"rfc822/rfc2047.h"
 #include	"rfc822/encode.h"
+#include	"rfc2646html.h"
 #include	"gpglib/gpglib.h"
 #include	"http11/http11.h"
 #include	"htmllibdir.h"
 #include	"unicode/unicode.h"
+#include	"courierauth.h"
 
 #include	<stdlib.h>
 #if HAVE_UNISTD_H
@@ -37,6 +39,9 @@
 #include	<ctype.h>
 #include	<fcntl.h>
 
+#define HASTEXTPLAIN(q) (rfc2045_searchcontenttype((q), "text/plain") != NULL)
+/* Also in attachments.c */
+
 extern const char *rfc822_mkdt(time_t);
 
 extern const char *sqwebmail_content_charset;
@@ -121,10 +126,9 @@ size_t	offset=strlen(name);
 
 		for (spc=0, i=0; hdr[i]; i++)
 		{
-			if (i + offset >= 75)
+			if (i + offset >= 75 && spc)
 			{
-				if (spc)
-					i = spc;
+			        i = spc;
 				offset = 0;
 				break;
 			}
@@ -248,7 +252,7 @@ void newmsg_create_multipart(int newdraftfd, const char *charset,
 
 
 static char	*newmsg_multipart_boundary(FILE *, const char *);
-static void newmsg_copy_attachments(FILE *, const char *);
+static void newmsg_copy_attachments(struct rfc2045 *, FILE *, const char *);
 
 void newmsg_copy_nonmime_headers(FILE *fp)
 {
@@ -277,7 +281,32 @@ char	*q;
 	}
 }
 
+void newmsg_copy_content_headers(FILE *fp)
+{
+char	*header, *value;
+char	*q;
+
+	while ((header=maildir_readheader(fp, &value, 1)) != NULL)
+	{
+		if (strncmp(header, "content-", 8)) continue;
+
+		for (q=header; *q; q++)
+		{
+			for (*q=toupper(*q); *q; q++)
+				if (*q == '-')	break;
+			if (!*q)
+				break;
+		}
+
+		maildir_writemsgstr(newdraftfd, header);
+		maildir_writemsgstr(newdraftfd, ": ");
+		maildir_writemsgstr(newdraftfd, value);
+		maildir_writemsgstr(newdraftfd, "\n");
+	}
+}
+
 static void do_save(const char *, size_t);
+static int do_save2(const char *, int, void *);
 
 char *newmsg_createdraft_do(const char *curdraft, const char *newmsg,
 	int keepheader)
@@ -290,15 +319,25 @@ const char *content_transfer_encoding;
 const char *charset;
 unsigned long prev_size=0;
 off_t	transferencodingpos;
+off_t	transferencoding2pos;
 int is_newevent=strcmp(cgi("form"), "newevent") == 0;
+struct	rfc2045	*rfcp;
+int has_attachments=0;
+char *buf;
+
 /* We're on the 'new event' screen */
 
-	if (curdraft)	/* Reuse a draft filename */
+ 	if (curdraft)	/* Reuse a draft filename */
 		newdraftfd=maildir_recreatemsg(INBOX "." DRAFTS, curdraft, &draftfilename);
 	else
 		newdraftfd=maildir_createmsg(INBOX "." DRAFTS, 0, &draftfilename);
 	if (newdraftfd < 0)	enomem();
 
+	pref_wikifmt=0;
+	if (strcmp(cgi("textformat"), "wiki") == 0)
+		pref_wikifmt=1;
+	pref_update();
+
 	fp=NULL;
 	if (curdraft)
 	{
@@ -362,7 +401,7 @@ int is_newevent=strcmp(cgi("form"), "newevent") == 0;
 	const	char *p=cgi("headerfrom");
 
 		if (!*p)	p=pref_from;
-		if (!p || !*p || access(NOCHANGINGFROM, 0) == 0)
+		if (!p || !*p || auth_getoptionenvint("wbnochangingfrom"))
 			p=login_fromhdr();
 
 		create_draftheader("From: ", p, 0, 1);
@@ -397,121 +436,224 @@ int is_newevent=strcmp(cgi("form"), "newevent") == 0;
 
 	/* If the message has attachments, calculate multipart boundary */
 
-	multipart_boundary=fp ? newmsg_multipart_boundary(fp, newmsg) : NULL;
+	rfcp=NULL;
 
-	if (multipart_boundary)
+	if (fp)
 	{
-	struct	rfc2045	*rfcp=rfc2045_fromfp(fp), *q;
-				/* Copy over existing charset */
-
+		rfcp=rfc2045_fromfp(fp);
 		if (!rfcp)
 		{
 			close(newdraftfd);
 			fclose(fp);
 			enomem();
 		}
+	}
 
-		rfc2045_mimeinfo(rfcp, &content_type,
-			&content_transfer_encoding, &charset);
+	multipart_boundary=newmsg_multipart_boundary(fp, newmsg);
 
+	if (rfcp && rfcp->firstpart &&
+	    strcmp((rfc2045_mimeinfo(rfcp, &content_type,
+			      &content_transfer_encoding, &charset),
+		    content_type), "multipart/mixed") == 0)
+	{
+		has_attachments=1;
 		newmsg_create_multipart(newdraftfd,
 			sqwebmail_content_charset, multipart_boundary);
 
 		maildir_writemsgstr(newdraftfd, "--");
 		maildir_writemsgstr(newdraftfd, multipart_boundary);
-
-		for (q=rfcp->firstpart; q; q=q->next)
-		{
-			if (q->isdummy)	continue;
-			rfc2045_mimeinfo(q, &content_type,
-				&content_transfer_encoding, &charset);
-			if (strcmp(content_type, "text/plain") == 0) break;
-		}
-
-		maildir_writemsgstr(newdraftfd,
-				    "\nContent-Type: text/plain; format=xdraft");
-
-		if (q)
-		{
-			maildir_writemsgstr(newdraftfd, "; charset=\"");
-			maildir_writemsgstr(newdraftfd,
-				sqwebmail_content_charset);
-			maildir_writemsgstr(newdraftfd, "\"");
-		}
-		rfc2045_free(rfcp);
-		maildir_writemsgstr(newdraftfd, "\n");
+		maildir_writemsgstr(newdraftfd,"\n");
 	}
 	else
 	{
-	struct	rfc2045 *rfcp;
-
-		if (fp)
-		{
-			rfcp=rfc2045_fromfp(fp);
-			if (!rfcp)
-			{
-				close(newdraftfd);
-				fclose(fp);
-				enomem();
-			}
-
-			rfc2045_mimeinfo(rfcp, &content_type,
-					&content_transfer_encoding, &charset);
-		}
-		else
-		{
-			rfcp=0;
-			charset=sqwebmail_content_charset;
-		}
-
-		maildir_writemsgstr(newdraftfd, "Mime-Version: 1.0\n"
-				    "Content-Type: text/plain; format=xdraft;"
-				    " charset=\"");
-		maildir_writemsgstr(newdraftfd, charset);
-		maildir_writemsgstr(newdraftfd, "\"\n");
-
-		if (rfcp)
-			rfc2045_free(rfcp);
+		maildir_writemsgstr(newdraftfd, "Mime-Version: 1.0\n");
 	}
 
+	if (pref_wikifmt)
+	{
+		++multipart_boundary[strlen(multipart_boundary)-1];
+
+		maildir_writemsgstr(newdraftfd,
+				    "Content-Type: multipart/alternative;"
+				    " boundary=\"");
+		maildir_writemsgstr(newdraftfd, multipart_boundary);
+		maildir_writemsgstr(newdraftfd, "\"\n"
+				    "\n"
+				    "\n"
+				    "--");
+		maildir_writemsgstr(newdraftfd, multipart_boundary);
+		maildir_writemsgstr(newdraftfd, "\n");
+	}
+
+	maildir_writemsgstr(newdraftfd,
+			    "Content-Type: text/plain; format=xdraft;"
+			    " charset=\"");
+	maildir_writemsgstr(newdraftfd, sqwebmail_content_charset);
+	maildir_writemsgstr(newdraftfd, "\"\n");
+
 	maildir_writemsgstr(newdraftfd, "Content-Transfer-Encoding: ");
-	transferencodingpos=writebufpos;
+	transferencoding2pos=transferencodingpos=writebufpos;
 	maildir_writemsgstr(newdraftfd, "7bit\n\n");
 
 	/*	maildir_writemsgstr(newdraftfd, "\n"); */
 
+	/*
+	** Because this is flowed text format, prepend an extra space to
+	** all lines that begin with a space.
+	*/
 
 	{
-	char	*buf=strdup(newmsg);
-	size_t	i,j;
+		size_t	i=0;
+		int pass;
 
-		for (i=j=0; buf[i]; i++)
-			if (buf[i] != '\r')	buf[j++]=buf[i];
+		buf=NULL;
+
+		for (pass=0; pass<2; pass++)
+		{
+			const char *p;
+
+			if (pass)
+			{
+				buf=malloc(i);
+				if (!buf)
+				{
+					if (fp)	fclose(fp);
+					if (rfcp)
+						rfc2045_free(rfcp);
+					close(newdraftfd);
+
+					enomem();
+				}
+			}
+			i=0;
+
+			for (p=newmsg; *p; )
+			{
+				if (*p == ' ')
+				{
+					if (pass)
+						buf[i]=' ';
+					++i;
+				}
+
+				while (*p)
+				{
+					if (*p == '\r')
+					{
+						++p;
+						continue;
+					}
+
+					if (pass)
+						buf[i]=*p;
+					++i;
+
+					if (*p++ == '\n')
+						break;
+				}
+			}
+
+			if (pass)
+				buf[i]=0;
+			++i;
+		}
 
 		/* Trim excessive trailing empty lines */
 
-		while (j > 4 && strncmp(buf+j-3, "\n\n\n", 3) == 0)
-			--j;
+		while (i > 2 && strncmp(buf+i-2, "\n", 1) == 0)
+			--i;
+		buf[i-1]=0;
 		filter_start(FILTER_FOR_SAVING, &do_save);
-		filter(buf, j);
+		filter(buf, i-1);
 		filter("\n", 1);
 		filter_end();
-		free(buf);
 	}
 
-	if ( multipart_boundary)
+	if (pref_wikifmt)
 	{
-		newmsg_copy_attachments(fp, multipart_boundary);
+		int rc;
+		struct rfc2646parser *flowparser;
+		struct rfc2646tohtml *flowtohtml;
+
+		maildir_writemsgstr(newdraftfd, "\n"
+				    "--");
+		maildir_writemsgstr(newdraftfd, multipart_boundary);
+		maildir_writemsgstr(newdraftfd, "\n"
+				    "Content-Type: text/html; charset=\"");
+		maildir_writemsgstr(newdraftfd, sqwebmail_content_charset);
+		maildir_writemsgstr(newdraftfd, "\"\n"
+				    "Content-Transfer-Encoding: ");
+		transferencoding2pos=writebufpos;
+		maildir_writemsgstr(newdraftfd, "7bit\n\n");
+
+		flowtohtml=rfc2646tohtml_alloc(do_save2, NULL);
+
+		if (!flowtohtml)
+		{
+			if (fp)	fclose(fp);
+			if (rfcp)
+				rfc2045_free(rfcp);
+			close(newdraftfd);
+
+			free(buf);
+			enomem();
+		}
+
+		flowparser=RFC2646TOWIKI_PARSEALLOC(flowtohtml);
+		if (!flowparser)
+		{
+			if (fp)	fclose(fp);
+			if (rfcp)
+				rfc2045_free(rfcp);
+			close(newdraftfd);
+			free(buf);
+			rfc2646tohtml_free(flowtohtml);
+			enomem();
+		}
+
+		rc=rfc2646_parse(flowparser, buf, strlen(buf));
+		if (rc == 0)
+			rc=rfc2646_parse(flowparser, "\n", 1);
+
+		rfc2646towiki_cleanup(flowtohtml);
+		rfc2646_free(flowparser);
+		rfc2646tohtml_free(flowtohtml);
+
+		if (rc)
+		{
+			if (fp)	fclose(fp);
+			if (rfcp)
+				rfc2045_free(rfcp);
+			close(newdraftfd);
+			enomem();
+		}
+
+		maildir_writemsgstr(newdraftfd, "\n"
+				    "--");
+		maildir_writemsgstr(newdraftfd, multipart_boundary);
+		maildir_writemsgstr(newdraftfd, "--\n");
+		--multipart_boundary[strlen(multipart_boundary)-1];
+
+	}
+	free(buf);
+
+	if ( multipart_boundary && rfcp && has_attachments)
+	{
+		newmsg_copy_attachments(rfcp, fp, multipart_boundary);
 		maildir_writemsgstr(newdraftfd, "\n--");
 		maildir_writemsgstr(newdraftfd, multipart_boundary);
 		maildir_writemsgstr(newdraftfd, "--\n");
 		free(multipart_boundary);
 	}
 	if (fp)	fclose(fp);
+	if (rfcp)
+		rfc2045_free(rfcp);
 
 	if ( maildir_writemsg_flush(newdraftfd) == 0 && writebuf8bit)
 	{
 		if (lseek(newdraftfd, transferencodingpos, SEEK_SET) < 0 ||
+			write(newdraftfd, "8", 1) != 1 ||
+		    lseek(newdraftfd, transferencoding2pos, SEEK_SET) < 0 ||
 			write(newdraftfd, "8", 1) != 1)
 		{
 			close(newdraftfd);
@@ -530,6 +672,12 @@ static void do_save(const char *p, size_t l)
 	maildir_writemsg(newdraftfd, p, l);
 }
 
+static int do_save2(const char *p, int l, void *dummy)
+{
+	maildir_writemsg(newdraftfd, p, l);
+	return 0;
+}
+
 /* Create message in the sent folder */
 
 static void sentmsg_copy(FILE *, struct rfc2045 *);
@@ -795,7 +943,7 @@ const char	*transfer_encoding=NULL;
 		maildir_writemsgstr(newdraftfd, value);
 		maildir_writemsgstr(newdraftfd, "\n");
 	}
-	if (access(USEXSENDER, 0) == 0)
+	if (auth_getoptionenvint("wbusexsender"))
 	{
 		maildir_writemsgstr(newdraftfd, "X-Sender: ");
 		maildir_writemsgstr(newdraftfd, login_returnaddr());
@@ -1129,15 +1277,15 @@ char	pidbuf[MAXLONGSIZE];
 char	timebuf[MAXLONGSIZE];
 time_t	t;
 char	cntbuf[MAXLONGSIZE];
-unsigned long cnt=0;
+static unsigned long cnt=0;
 char	*p;
 
 	sprintf(pidbuf, "%lu", (unsigned long)getpid());
 	time(&t);
 	sprintf(timebuf, "%lu", (unsigned long)t);
 	sprintf(cntbuf, "%lu", cnt++);
-	p=malloc(strlen(pidbuf)+strlen(timebuf) +strlen(cntbuf)+10);
-	sprintf(p, "=_%s_%s_%s", cntbuf, pidbuf, timebuf);
+	p=malloc(strlen(pidbuf)+strlen(timebuf) +strlen(cntbuf)+20);
+	sprintf(p, "=_%s_%s_%s_000", cntbuf, pidbuf, timebuf);
 	return (p);
 }
 
@@ -1189,49 +1337,29 @@ const char *line;
 
 /* multipart_boundary - determine if current draft has attachments */
 
-static struct rfc2045 *copyrfc2045;
-
 static char	*newmsg_multipart_boundary(FILE *f, const char *msg)
 {
-char	*p=0;
-
-	copyrfc2045=rfc2045_fromfp(f);
-	if (!copyrfc2045)
-	{
-		fclose(f);
-		close(newdraftfd);
-		enomem();
-	}
-	if ( copyrfc2045->firstpart == 0)
-	{
-		rfc2045_free(copyrfc2045);
-		return (0);
-	}
+	char	*p=0;
 
 	do
 	{
 		if (p)	free(p);
 		p=multipart_boundary_create();
 	} while (multipart_boundary_checks(p, msg)
-		|| multipart_boundary_checkf(p, f));
+		 || (f && multipart_boundary_checkf(p, f)));
 	return (p);
 }
 
-static void	newmsg_copy_attachments(FILE *f, const char *boundary)
+static void	newmsg_copy_attachments(struct rfc2045 *rfcp,
+					FILE *f, const char *boundary)
 {
 struct	rfc2045 *p;
 int	foundtextplain=0;
-const char *content_type;
-const char *content_transfer_encoding;
-const char *charset;
 
-	for (p=copyrfc2045->firstpart; p; p=p->next)
+	for (p=rfcp->firstpart; p; p=p->next)
 	{
 		if (p->isdummy)	continue;
-		rfc2045_mimeinfo(p, &content_type,
-			&content_transfer_encoding, &charset);
-		if (!foundtextplain && strcmp(content_type,
-				"text/plain") == 0)
+		if (!foundtextplain && HASTEXTPLAIN(p))
 		{	/* Previous version of this message */
 
 			foundtextplain=1;
@@ -1242,5 +1370,4 @@ const char *charset;
 		maildir_writemsgstr(newdraftfd, "\n");
 		sentmsg_copy(f, p);	/* Reuse some code */
 	}
-	rfc2045_free(copyrfc2045);
 }
