@@ -5,7 +5,7 @@
 
 
 /*
-** $Id: sqwebmail.c,v 1.134 2006/05/17 01:42:46 mrsam Exp $
+** $Id: sqwebmail.c,v 1.138 2006/07/25 01:21:17 mrsam Exp $
 */
 #include	"sqwebmail.h"
 #include	"sqconfig.h"
@@ -876,8 +876,7 @@ void output_form(const char *formname)
 			sleep(5);
 		if (pid == 0)
 		{
-			close(0);
-			dup(pipefd[0]);
+			dup2(pipefd[0], 0);
 			close(pipefd[0]);
 			close(pipefd[1]);
 			execl(GZIP, "gzip", "-c", (char *)0);
@@ -888,8 +887,7 @@ void output_form(const char *formname)
 		}
 
 		gzip_save_fd=dup(1);
-		close(1);
-		dup(pipefd[1]);
+		dup2(pipefd[1], 1);
 		close(pipefd[1]);
 		close(pipefd[0]);
 	}
@@ -907,8 +905,7 @@ void output_form(const char *formname)
 		/* Restore original stdout */
 
 		fflush(stdout);
-		close(1);
-		dup(gzip_save_fd);
+		dup2(gzip_save_fd, 1);
 		close(gzip_save_fd);
 		gzip_save_fd= -1;
 		while ((p2=wait(&waitstat)) >= 0 && p2 != pid)
@@ -1367,12 +1364,9 @@ static void do_output_form_loop(FILE *f)
 			** things up in Netscape.
 			*/
 
-			printf("<textarea style=\"font-family: courier;\" cols=\"40\" rows=\"4\" "
-			       "name=\"mailinglists\" wrap=\"soft\">");
 			output_attrencoded(p ? p:"");
 			if (p)
 				free(p);
-			printf("</textarea>");
 		}
 		else if (strcmp(kw, "AUTORESPONSE") == 0)
 		{
@@ -1589,9 +1583,11 @@ static void do_output_form_loop(FILE *f)
 		else if (strncmp(kw, "select:", 7) == 0)
 		{
 		const char *name=strtok(kw+7, ":");
+		const char *class=strtok(0, ":");
 		const char *size=strtok(0, ":");
 
 			printf("<select name=\"%s\"", name ? name:"");
+			if (class)	printf(" class=\"%s\"", class);
 			if (size)	printf(" size=\"%s\"", size);
 			printf(">");
 		}
@@ -1978,8 +1974,7 @@ void cleanup()
 #ifdef GZIP
 	if (gzip_save_fd >= 0)	/* Restore original stdout */
 	{
-		close(1);
-		dup(gzip_save_fd);
+		dup2(gzip_save_fd, 1);
 		close(gzip_save_fd);
 		gzip_save_fd= -1;
 	}
@@ -2030,17 +2025,18 @@ static void setlang()
 
 static void init_default_locale()
 {
-char	*cl=http11_best_content_language(HTMLLIBDIR,
+char	*templatedir=get_templatedir();
+char	*cl=http11_best_content_language(templatedir,
 			getenv("HTTP_ACCEPT_LANGUAGE"));
 
 	sqwebmail_content_language=
-				http11_content_language(HTMLLIBDIR, cl);
+				http11_content_language(templatedir, cl);
 	sqwebmail_content_locale=
-			http11_content_locale(HTMLLIBDIR, cl);
+			http11_content_locale(templatedir, cl);
 	sqwebmail_content_ispelldict=
-			http11_content_ispelldict(HTMLLIBDIR, cl);
+			http11_content_ispelldict(templatedir, cl);
 	sqwebmail_content_charset=
-			http11_content_charset(HTMLLIBDIR, cl);
+			http11_content_charset(templatedir, cl);
 
 	free(cl);
 #if	HAVE_LOCALE_H
@@ -2766,7 +2762,11 @@ time_t	timeouthard=TIMEOUTHARD;
 		{
 			setgid(getgid());
 			setuid(getuid());	/* Drop root prevs */
-			chdir("/");
+			if (chdir("/") < 0)
+			{
+				output_form("expired.html");
+				return (0);
+			}
 			cgi_setup();
 			init_default_locale();
 			free(pi);
