@@ -1,11 +1,11 @@
 /*
-** $Id: sqwebmail.h,v 1.19 2004/02/29 20:30:56 mrsam Exp $
+** $Id: sqwebmail.h,v 1.21 2006/05/17 01:42:46 mrsam Exp $
 */
 #ifndef	sqwebmail_h
 #define	sqwebmail_h
 
 /*
-** Copyright 1998 - 2003 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2006 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -34,7 +34,7 @@ extern void error3(const char *, int, const char *, const char *, int);
 /* Socket filename */
 
 #define SOCKFILENAME SOCKDIR "/sqwebmail.sock"
-#define SOCKENVIRONLEN 4096
+#define SOCKENVIRONLEN 8192
 
 #define VALIDCGIVAR(p) \
 		    (strncmp((p), "DOCUMENT_", 9) == 0 || \
@@ -55,6 +55,10 @@ extern void error3(const char *, int, const char *, const char *, int);
 
 #define	IPFILE		"sqwebmail-ip"
 
+/* Last time the sent folder was renamed */
+
+#define SENTSTAMP	"sqwebmail-sentstamp"
+
 /* File that keeps the time of last access */
 
 #define	TIMESTAMP	"sqwebmail-timestamp"
